"""
This module provides access to Blender's text drawing functions.


--------------------

Example of using the blf module. For this module to work we
need to use the GPU module gpu as well.

```../examples/blf.0.py```


--------------------

Example showing how text can be drawn into an image.
This can be done by binding an image buffer (imbuf) to the font's ID.

```../examples/blf.1.py```

"""

import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import imbuf.types

def aspect(fontid: int, aspect: float) -> None:
    """Set the aspect for drawing text.

    :param fontid: The id of the typeface as returned by `blf.load`, for default font use 0.
    :param aspect: The aspect ratio for non-uniform scaling of text.
    """

def bind_imbuf(
    fontid: int, imbuf: imbuf.types.ImBuf, *, display_name: None | str | None = None
) -> None:
    """Context manager to draw text into an image buffer instead of the GPUs context.

    :param fontid: The id of the typeface as returned by `blf.load`, for default font use 0.
    :param imbuf: The image to draw into.
    :param display_name: Ignored (formerly a color-space transform name), kept for backwards compatibility.
    :return: The BLF ImBuf context manager.
    """

def clipping(fontid: int, xmin: float, ymin: float, xmax: float, ymax: float) -> None:
    """Set the clipping, enable/disable using `CLIPPING`.

    :param fontid: The id of the typeface as returned by `blf.load`, for default font use 0.
    :param xmin: Left edge of the clipping rectangle.
    :param ymin: Bottom edge of the clipping rectangle.
    :param xmax: Right edge of the clipping rectangle.
    :param ymax: Top edge of the clipping rectangle.
    """

def color(fontid: int, r: float, g: float, b: float, a: float) -> None:
    """Set the color for drawing text.

    :param fontid: The id of the typeface as returned by `blf.load`, for default font use 0.
    :param r: Red channel 0.0 - 1.0.
    :param g: Green channel 0.0 - 1.0.
    :param b: Blue channel 0.0 - 1.0.
    :param a: Alpha channel 0.0 - 1.0.
    """

def dimensions(fontid: int, text: str) -> tuple[float, float]:
    """Return the width and height of the text.

    :param fontid: The id of the typeface as returned by `blf.load`, for default font use 0.
    :param text: The text to measure.
    :return: The width and height of the text.
    """

def disable(fontid: int, option: int) -> None:
    """Disable a font drawing option.

    :param fontid: The id of the typeface as returned by `blf.load`, for default font use 0.
    :param option: One of `ROTATION`, `CLIPPING`, `SHADOW`, `MONOCHROME` or `WORD_WRAP`.
    """

def draw(fontid: int, text: str) -> None:
    """Draw text in the current context.

    :param fontid: The id of the typeface as returned by `blf.load`, for default font use 0.
    :param text: The text to draw.
    """

def draw_buffer(fontid: int, text: str) -> None:
    """Draw text into the image buffer bound via `blf.bind_imbuf`.

    :param fontid: The id of the typeface as returned by `blf.load`, for default font use 0.
    :param text: The text to draw into the bound image buffer.
    """

def enable(fontid: int, option: int) -> None:
    """Enable a font drawing option.

    :param fontid: The id of the typeface as returned by `blf.load`, for default font use 0.
    :param option: One of `ROTATION`, `CLIPPING`, `SHADOW`, `MONOCHROME` or `WORD_WRAP`.
    """

def load(filepath: bytes | str) -> int:
    """Load a new font.

    :param filepath: The filepath of the font.
    :return: The new fonts fontid or -1 if there was an error.
    """

def position(fontid: int, x: float, y: float, z: float) -> None:
    """Set the position for drawing text.

    :param fontid: The id of the typeface as returned by `blf.load`, for default font use 0.
    :param x: X axis position to draw the text.
    :param y: Y axis position to draw the text.
    :param z: Z axis position to draw the text (typically 0).
    """

def rotation(fontid: int, angle: float) -> None:
    """Set the text rotation angle, enable/disable using `ROTATION`.

    :param fontid: The id of the typeface as returned by `blf.load`, for default font use 0.
    :param angle: The angle for text drawing to use (in radians).
    """

def shadow(fontid: int, level: int, r: float, g: float, b: float, a: float) -> None:
    """Shadow options, enable/disable using `SHADOW`.

    :param fontid: The id of the typeface as returned by `blf.load`, for default font use 0.
    :param level: The shadow type: 0 for none, 3 for 3x3 blur, 5 for 5x5 blur or 6 for outline. Other values raise a `TypeError`.
    :param r: Shadow color (red channel 0.0 - 1.0).
    :param g: Shadow color (green channel 0.0 - 1.0).
    :param b: Shadow color (blue channel 0.0 - 1.0).
    :param a: Shadow color (alpha channel 0.0 - 1.0).
    """

def shadow_offset(fontid: int, x: int, y: int) -> None:
    """Set the offset for shadow text, enable/disable using `SHADOW`.

    :param fontid: The id of the typeface as returned by `blf.load`, for default font use 0.
    :param x: Horizontal shadow offset value in pixels.
    :param y: Vertical shadow offset value in pixels.
    """

def size(fontid: int, size: float) -> None:
    """Set the size for drawing text.

    :param fontid: The id of the typeface as returned by `blf.load`, for default font use 0.
    :param size: Point size of the font.
    """

def unload(filepath: bytes | str) -> None:
    """Unload an existing font.

    :param filepath: The filepath of the font.
    """

def word_wrap(fontid: int, wrap_width: int) -> None:
    """Set the wrap width, enable/disable using `WORD_WRAP`.

    :param fontid: The id of the typeface as returned by `blf.load`, for default font use 0.
    :param wrap_width: The width (in pixels) to wrap words at.
    """

CLIPPING: typing.Any
""" Constant value 2
"""

MONOCHROME: typing.Any
""" Constant value 128
"""

ROTATION: typing.Any
""" Constant value 1
"""

SHADOW: typing.Any
""" Constant value 4
"""

WORD_WRAP: typing.Any
""" Constant value 64
"""



"""
This module contains application values that remain unchanged during runtime.

bpy.app.handlers.rst
bpy.app.translations.rst
bpy.app.icons.rst
bpy.app.timers.rst

:maxdepth: 1
:caption: Submodules

"""

import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import bpy.stub_internal.rna_enums

from . import handlers as handlers
from . import icons as icons
from . import timers as timers
from . import translations as translations

def help_text(*, all: bool | None = False) -> str:
    """Return the help text as a string.

    :param all: Return all arguments, even those which arent available for the current platform.
    :return: Help text.
    """

def is_job_running(job_type: bpy.stub_internal.rna_enums.WmJobTypeItems) -> bool:
    """Check whether a job of the given type is running.

    :param job_type: job type in `rna_enum_wm_job_type_items`.
    :return: Whether a job of the given type is currently running.
    """

def memory_usage_undo() -> int:
    """Get undo memory usage information.

    :return: Memory usage of the undo stack in bytes.
    """

alembic: typing.Any
""" Constant value bpy.app.alembic(supported=True, version=(1, 8, 3), version_string= 1,  8,  3)
"""

autoexec_fail: bool
""" Boolean, True when auto-execution of scripts failed (read-only).
"""

autoexec_fail_message: str
""" String, message describing the auto-execution failure (read-only).
"""

autoexec_fail_quiet: bool
""" Boolean, True when auto-execution failure should be quiet, set after the warning is shown once for the current blend file (read-only).
"""

background: bool
""" Boolean, True when blender is running without a user interface (started with -b)
"""

binary_path: str
""" The location of Blenders executable, useful for utilities that open new instances. Read-only unless Blender is built as a Python module - in this case the value is an empty string which script authors may point to a Blender binary.
"""

build_branch: bytes
""" The branch this blender instance was built from
"""

build_cflags: bytes
""" C compiler flags
"""

build_commit_date: bytes
""" The date of the commit this Blender instance was built from
"""

build_commit_time: bytes
""" The time of the commit this Blender instance was built from
"""

build_commit_timestamp: int
""" The unix timestamp of the commit this Blender instance was built from
"""

build_cxxflags: bytes
""" C++ compiler flags
"""

build_date: bytes
""" The date this Blender instance was built
"""

build_hash: bytes
""" The commit hash this Blender instance was built with
"""

build_linkflags: bytes
""" Binary linking flags
"""

build_options: typing.Any
""" Constant value bpy.app.build_options(bullet=True, codec_avi=False, codec_ffmpeg=True, codec_sndfile=True, compositor_cpu=True, cycles=True, cycles_osl=True, freestyle=True, image_cineon=True, image_dds=True, image_hdr=True, image_openexr=True, image_openjpeg=True, image_tiff=True, image_webp=True, input_ndof=True, audaspace=True, international=True, openal=True, opensubdiv=True, sdl=False, coreaudio=False, jack=False, pulseaudio=False, wasapi=False, libmv=True, mod_oceansim=True, mod_remesh=True, io_wavefront_obj=True, io_ply=True, io_stl=True, io_fbx=True, io_gpencil=True, opencolorio=True, openmp=False, openvdb=True, alembic=True, usd=True, fluid=True, xr_openxr=True, potrace=True, pugixml=True, haru=True, experimental_features=True)
"""

build_platform: bytes
""" The platform this blender instance was built for
"""

build_system: bytes
""" Build system used
"""

build_time: bytes
""" The time this Blender instance was built
"""

build_type: bytes
""" The type of build (Release, Debug)
"""

cachedir: None | str
""" String, the cache directory used by blender (read-only).If the parent of the cache folder (i.e. the part of the path that is not Blender-specific) does not exist, returns None.
"""

debug: bool
""" Boolean, for debug info (started with --debug / --debug-* matching this attribute name).
"""

debug_depsgraph: bool
""" Boolean, for debug info (started with --debug / --debug-* matching this attribute name).
"""

debug_depsgraph_build: bool
""" Boolean, for debug info (started with --debug / --debug-* matching this attribute name).
"""

debug_depsgraph_eval: bool
""" Boolean, for debug info (started with --debug / --debug-* matching this attribute name).
"""

debug_depsgraph_pretty: bool
""" Boolean, for debug info (started with --debug / --debug-* matching this attribute name).
"""

debug_depsgraph_tag: bool
""" Boolean, for debug info (started with --debug / --debug-* matching this attribute name).
"""

debug_depsgraph_time: bool
""" Boolean, for debug info (started with --debug / --debug-* matching this attribute name).
"""

debug_events: bool
""" Boolean, for debug info (started with --debug / --debug-* matching this attribute name).
"""

debug_freestyle: bool
""" Boolean, for debug info (started with --debug / --debug-* matching this attribute name).
"""

debug_handlers: bool
""" Boolean, for debug info (started with --debug / --debug-* matching this attribute name).
"""

debug_io: bool
""" Boolean, for debug info (started with --debug / --debug-* matching this attribute name).
"""

debug_python: bool
""" Boolean, for debug info (started with --debug / --debug-* matching this attribute name).
"""

debug_simdata: bool
""" Boolean, for debug info (started with --debug / --debug-* matching this attribute name).
"""

debug_value: int
""" Integer value which can be set to non-zero values for testing purposes.
"""

debug_wm: bool
""" Boolean, for debug info (started with --debug / --debug-* matching this attribute name).
"""

driver_namespace: dict[str, typing.Any]
""" Dictionary for drivers namespace, editable in-place, reset on file load (read-only).
"""

factory_startup: bool
""" Boolean, True when blender is running with --factory-startup
"""

ffmpeg: typing.Any
""" Constant value bpy.app.ffmpeg(supported=True, avcodec_version=(61, 19, 101), avcodec_version_string=61, 19, 101, avdevice_version=(61, 3, 100), avdevice_version_string=61,  3, 100, avformat_version=(61, 7, 100), avformat_version_string=61,  7, 100, avutil_version=(59, 39, 100), avutil_version_string=59, 39, 100, swscale_version=(8, 3, 100), swscale_version_string= 8,  3, 100)
"""

module: bool
""" Boolean, True when running Blender as a python module
"""

ocio: typing.Any
""" Constant value bpy.app.ocio(supported=True, version=(2, 5, 0), version_string= 2,  5,  0)
"""

oiio: typing.Any
""" Constant value bpy.app.oiio(supported=True, version=(3, 1, 7), version_string= 3,  1,  7)
"""

online_access: bool
""" Boolean, true when internet access is allowed by Blender & 3rd party scripts (read-only).
"""

online_access_override: bool
""" Boolean, true when internet access preference is overridden by the command line (read-only).
"""

opensubdiv: typing.Any
""" Constant value bpy.app.opensubdiv(supported=True, version=(3, 7, 0), version_string= 3,  7,  0)
"""

openvdb: typing.Any
""" Constant value bpy.app.openvdb(supported=True, version=(13, 0, 0), version_string=13,  0,  0)
"""

portable: bool
""" Boolean, True unless blender was built to reference absolute paths (on UNIX).
"""

python_args: tuple[str, ...]
""" Leading arguments to use when calling Python directly (via sys.executable). These arguments match settings Blender uses to ensure Python runs with a compatible environment (read-only).
"""

render_icon_size: int
""" Reference size for icon renders (read-only).
"""

render_preview_size: int
""" Reference size for preview renders (read-only).
"""

sdl: typing.Any
""" Constant value bpy.app.sdl(supported=False, version=(0, 0, 0), version_string=Unknown)
"""

tempdir: str
""" String, the temp directory used by blender (read-only).
"""

usd: typing.Any
""" Constant value bpy.app.usd(supported=True, version=(0, 25, 8), version_string= 0, 25,  8)
"""

use_event_simulate: bool
""" Boolean, for application behavior (started with --enable-* matching this attribute name)
"""

use_userpref_skip_save_on_exit: bool
""" Boolean, for application behavior (started with --enable-* matching this attribute name)
"""

version: tuple[int, int, int]
""" The Blender version as a tuple of 3 numbers (major, minor, micro). eg. (4, 3, 1)
"""

version_cycle: str
""" The release status of this build alpha/beta/rc/release
"""

version_file: tuple[int, int, int]
""" The Blender File version, as a tuple of 3 numbers (major, minor, file sub-version), that will be used to save a .blend file. The last item in this tuple indicates the file sub-version, which is different from the release micro version (the last item of the bpy.app.version tuple). The file sub-version can be incremented multiple times while a Blender version is under development. This value is, and should be, used for handling compatibility changes between Blender versions
"""

version_string: str
""" The Blender version formatted as a string
"""



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import bpy.stub_internal.rna_enums

def convert_volume_to_mesh(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Convert the volume of a world to a mesh. The worlds volume used to be rendered by EEVEE Legacy. Conversion is needed for it to render properly

    :return: Result of the operator call.
    """

def new(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Create a new world Data-Block

    :return: Result of the operator call.
    """



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import bl_ui.node_add_menu
import bpy.types

class NODE_MT_shader_node_all_base(bl_ui.node_add_menu.NodeMenu):
    """A base-class defining the shared methods for AddNodeMenu and SwapNodeMenu."""

    bl_label: typing.Any
    bl_rna: typing.Any
    bl_translation_context: typing.Any
    id_data: typing.Any
    menu_path: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

class NODE_MT_shader_node_color_base(bl_ui.node_add_menu.NodeMenu):
    """A base-class defining the shared methods for AddNodeMenu and SwapNodeMenu."""

    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

class NODE_MT_shader_node_displacement_base(bl_ui.node_add_menu.NodeMenu):
    """A base-class defining the shared methods for AddNodeMenu and SwapNodeMenu."""

    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, _context) -> None:
        """

        :param _context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class NODE_MT_shader_node_input_base(bl_ui.node_add_menu.NodeMenu):
    """A base-class defining the shared methods for AddNodeMenu and SwapNodeMenu."""

    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

class NODE_MT_shader_node_math_base(bl_ui.node_add_menu.NodeMenu):
    """A base-class defining the shared methods for AddNodeMenu and SwapNodeMenu."""

    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any
    menu_path: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

class NODE_MT_shader_node_output_base(bl_ui.node_add_menu.NodeMenu):
    """A base-class defining the shared methods for AddNodeMenu and SwapNodeMenu."""

    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

class NODE_MT_shader_node_shader_base(bl_ui.node_add_menu.NodeMenu):
    """A base-class defining the shared methods for AddNodeMenu and SwapNodeMenu."""

    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class NODE_MT_shader_node_texture_base(bl_ui.node_add_menu.NodeMenu):
    """A base-class defining the shared methods for AddNodeMenu and SwapNodeMenu."""

    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, _context) -> None:
        """

        :param _context:
        """

class NODE_MT_shader_node_utilities_base(bl_ui.node_add_menu.NodeMenu):
    """A base-class defining the shared methods for AddNodeMenu and SwapNodeMenu."""

    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

class NODE_MT_shader_node_vector_base(bl_ui.node_add_menu.NodeMenu):
    """A base-class defining the shared methods for AddNodeMenu and SwapNodeMenu."""

    bl_label: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any
    menu_path: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

def cycles_shader_nodes_poll(context) -> None: ...
def eevee_shader_nodes_poll(context) -> None: ...
def line_style_shader_nodes_poll(context) -> None: ...
def object_eevee_shader_nodes_poll(context) -> None: ...
def object_light_shader_nodes_poll(context) -> None: ...
def object_material_shader_nodes_poll(context) -> None: ...
def object_not_eevee_shader_nodes_poll(context) -> None: ...
def object_shader_nodes_poll(context) -> None: ...
def world_shader_nodes_poll(context) -> None: ...



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import _bpy_types
import bpy.types

class RENDER_OT_swap_dimensions(_bpy_types.Operator):
    bl_description: typing.Any
    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def execute(self, context) -> None:
        """

        :param context:
        """



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt

def bmesh_linked_uv_islands(bm, uv_layer) -> list[list[int]]:
    """Returns lists of faces connected by UV islands.For meshes use `bpy.types.Mesh.mesh_linked_uv_islands` instead.

    :param bm: the bmesh used to group with.
    :param uv_layer: the UV layer to source UVs from.
    :return: list of lists containing polygon indices
    """

def match_uv(face, vert, uv, uv_layer) -> None: ...



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import bpy.stub_internal.rna_enums

def assign_default_button(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set this propertys current value as the new default

    :return: Result of the operator call.
    """

def button_execute(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    skip_depressed: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Presses active button

    :param skip_depressed: Skip Depressed, (optional)
    :return: Result of the operator call.
    """

def button_string_clear(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Unsets the text of the active button

    :return: Result of the operator call.
    """

def copy_as_driver_button(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Create a new driver with this property as input, and copy it to the internal clipboard. Use Paste Driver to add it to the target property, or Paste Driver Variables to extend an existing driver

    :return: Result of the operator call.
    """

def copy_data_path_button(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    full_path: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Copy the RNA data path for this property to the clipboard

    :param full_path: full_path, Copy full data path (optional)
    :return: Result of the operator call.
    """

def copy_driver_to_selected_button(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    all: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Copy the propertys driver from the active item to the same property of all selected items, if the same property exists

    :param all: All, Copy to selected the drivers of all elements of the array (optional)
    :return: Result of the operator call.
    """

def copy_python_command_button(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Copy the Python command matching this button

    :return: Result of the operator call.
    """

def copy_to_selected_button(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    all: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Copy the propertys value from the active item to the same property of all selected items if the same property exists

    :param all: All, Copy to selected all elements of the array (optional)
    :return: Result of the operator call.
    """

def drop_color(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    color: collections.abc.Sequence[float] | None = (0.0, 0.0, 0.0, 0.0),
    gamma: bool | None = False,
    has_alpha: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Drop colors to buttons

    :param color: Color, Source color (array of 4 items, in [0, inf], optional)
    :param gamma: Gamma Corrected, The source color is gamma corrected (optional)
    :param has_alpha: Has Alpha, The source color contains an Alpha component (optional)
    :return: Result of the operator call.
    """

def drop_material(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    session_uid: int | None = 0,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Drag material to Material slots in Properties

    :param session_uid: Session UID, Session UID of the data-block to use by the operator (in [-inf, inf], optional)
    :return: Result of the operator call.
    """

def drop_name(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    string: str | None = "",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Drop name to button

    :param string: String, The string value to drop into the button (optional, never None)
    :return: Result of the operator call.
    """

def editsource(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Edit UI source code of the active button

    :return: Result of the operator call.
    """

def eyedropper_bone(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Sample a bone from the 3D View or the Outliner to store in a property

    :return: Result of the operator call.
    """

def eyedropper_color(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    prop_data_path: str | None = "",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Sample a color from the Blender window to store in a property

    :param prop_data_path: Data Path, Path of property to be set with the depth (optional, never None)
    :return: Result of the operator call.
    """

def eyedropper_colorramp(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Sample a color band

    :return: Result of the operator call.
    """

def eyedropper_colorramp_point(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Point-sample a color band

    :return: Result of the operator call.
    """

def eyedropper_depth(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    prop_data_path: str | None = "",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Sample depth from the 3D view

    :param prop_data_path: Data Path, Path of property to be set with the depth (optional, never None)
    :return: Result of the operator call.
    """

def eyedropper_driver(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    mapping_type: typing.Literal[
        "SINGLE_MANY", "DIRECT", "MATCH", "NONE_ALL", "NONE_SINGLE"
    ]
    | None = "SINGLE_MANY",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Pick a property to use as a driver target

        :param mapping_type: Mapping Type, Method used to match target and driven properties (optional)

    SINGLE_MANY
    All from Target -- Drive all components of this property using the target picked.

    DIRECT
    Single from Target -- Drive this component of this property using the target picked.

    MATCH
    Match Indices -- Create drivers for each pair of corresponding elements.

    NONE_ALL
    Manually Create Later -- Create drivers for all properties without assigning any targets yet.

    NONE_SINGLE
    Manually Create Later (Single) -- Create driver for this property only and without assigning any targets yet.
        :return: Result of the operator call.
    """

def eyedropper_grease_pencil_color(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    mode: typing.Literal["MATERIAL", "PALETTE", "BRUSH"] | None = "MATERIAL",
    material_mode: typing.Literal["STROKE", "FILL", "BOTH"] | None = "STROKE",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Sample a color from the Blender Window and create Grease Pencil material

    :param mode: Mode, (optional)
    :param material_mode: Material Mode, (optional)
    :return: Result of the operator call.
    """

def eyedropper_id(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Sample a data-block from the 3D View to store in a property

    :return: Result of the operator call.
    """

def jump_to_target_button(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Switch to the target object or bone

    :return: Result of the operator call.
    """

def list_start_filter(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Start entering filter text for the list in focus

    :return: Result of the operator call.
    """

def override_add_button(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    all: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Create an override operation

    :param all: All, Add overrides for all elements of the array (optional)
    :return: Result of the operator call.
    """

def override_idtemplate_clear(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Delete the selected local override and relink its usages to the linked data-block if possible, else reset it and mark it as non editable

    :return: Result of the operator call.
    """

def override_idtemplate_make(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Create a local override of the selected linked data-block, and its hierarchy of dependencies

    :return: Result of the operator call.
    """

def override_idtemplate_reset(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Reset the selected local override to its linked reference values

    :return: Result of the operator call.
    """

def override_remove_button(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    all: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Remove an override operation

    :param all: All, Reset to default values all elements of the array (optional)
    :return: Result of the operator call.
    """

def reloadtranslation(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Force a full reload of UI translation

    :return: Result of the operator call.
    """

def reset_default_button(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    all: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Reset this propertys value to its default value

    :param all: All, Reset to default values all elements of the array (optional)
    :return: Result of the operator call.
    """

def unset_property_button(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Clear the property and use default or generated value in operators

    :return: Result of the operator call.
    """

def view_drop(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Drag and drop onto a data-set or item within the data-set

    :return: Result of the operator call.
    """

def view_item_delete(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Delete selected list item

    :return: Result of the operator call.
    """

def view_item_rename(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Rename the active item in the data-set view

    :return: Result of the operator call.
    """

def view_item_select(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    wait_to_deselect_others: bool | None = False,
    use_select_on_click: bool | None = False,
    mouse_x: int | None = 0,
    mouse_y: int | None = 0,
    extend: bool | None = False,
    range_select: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Activate selected view item

    :param wait_to_deselect_others: Wait to Deselect Others, (optional)
    :param use_select_on_click: Act on Click, Instead of selecting on mouse press, wait to see if theres drag event. Otherwise select on mouse release (optional)
    :param mouse_x: Mouse X, (in [-inf, inf], optional)
    :param mouse_y: Mouse Y, (in [-inf, inf], optional)
    :param extend: extend, Extend Selection (optional)
    :param range_select: Range Select, Select all between clicked and active items (optional)
    :return: Result of the operator call.
    """

def view_scroll(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Undocumented, consider contributing.

    :return: Result of the operator call.
    """

def view_start_filter(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Start entering filter text for the data-set in focus

    :return: Result of the operator call.
    """
